@@ -1,4 +1,4 @@
-// Copyright © 2011-15 Richard Kettlewell.
+// Copyright © 2011-16 Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 #include "Errors.h"
 #include "Conf.h"
 #include "IO.h"
+#include "Utils.h"
 #include <getopt.h>
 #include <cstdlib>
 
@@ -143,25 +144,25 @@ void Command::parse(int argc, const char *const *argv) {
     case 'e': email = new std::string(optarg); break;
     case 'p': prune = true; break;
     case 'P': pruneIncomplete = true; break;
-    case 's': stores.push_back(optarg); warnStore = true; break;
+    case 's': stores.push_back(optarg); enable_warning(WARNING_STORE); break;
     case 'c': configPath = optarg; break;
     case 'w': wait = true; break;
-    case 'n': act = false; verbose = true; break;
+    case 'n': act = false; enable_warning(WARNING_VERBOSE); break;
     case 'f': force = true; break;
-    case 'v': verbose = true; break;
+    case 'v': enable_warning(WARNING_VERBOSE); break;
     case 'd': debug = true; break;
     case 'D': database = optarg; break;
     case RETIRE_DEVICE: retireDevice = true; break;
     case RETIRE: retire = true; break;
-    case WARN_UNKNOWN: warnUnknown = true; break;
-    case WARN_STORE: warnStore = true; break;
-    case WARN_UNREACHABLE: warnUnreachable = true; break;
-    case WARN_PARTIAL: warnPartial = true; break;
-    case NO_WARN_PARTIAL: warnPartial = false; break;
-    case REPEAT_ERRORS: repeatErrorLogs = true; break;
-    case NO_REPEAT_ERRORS: repeatErrorLogs = false; break;
+    case WARN_UNKNOWN: enable_warning(WARNING_UNKNOWN); break;
+    case WARN_STORE: enable_warning(WARNING_STORE); break;
+    case WARN_UNREACHABLE: enable_warning(WARNING_UNREACHABLE); break;
+    case WARN_PARTIAL: enable_warning(WARNING_PARTIAL); break;
+    case NO_WARN_PARTIAL: disable_warning(WARNING_PARTIAL); break;
+    case REPEAT_ERRORS: enable_warning(WARNING_ERRORLOGS); break;
+    case NO_REPEAT_ERRORS: disable_warning(WARNING_ERRORLOGS); break;
     case LOG_VERBOSITY: logVerbosity = getVerbosity(optarg); break;
-    case 'W': warnUnknown = warnStore = warnUnreachable = warnPartial = true; break;
+    case 'W': enable_warning(static_cast<unsigned>(-1)); break;
     case DUMP_CONFIG: dumpConfig = true; break;
     default: exit(1);
     }
@@ -199,28 +200,11 @@ void Command::parse(int argc, const char *const *argv) {
   if(backup || prune || pruneIncomplete || retire) {
     // Volumes to back up, prune or retire
     if(optind < argc) {
-      for(n = optind; n < argc; ++n) {
-        // Establish the sense of this entry
-        bool sense;
-        const char *s = argv[n], *t;
-        if(*s == '-' || *s == '!') {
-          sense = false;
-          ++s;
-        } else
-          sense = true;
-        if((t = strchr(s, ':'))) {
-          // A host:volume pair
-          selections.push_back(Selection(std::string(s, t - s), t + 1, sense));
-        } else {
-          // Just a host
-          selections.push_back(Selection(s, "*", sense));
-        }
-      }
+      for(n = optind; n < argc; ++n)
+        selections.add(argv[n]);
     } else {
       if(retire)
         throw CommandError("no volumes specified to retire");
-      // No volumes requested = back up/prune everything
-      selections.push_back(Selection("*", "*", true));
     }
   }
   if(retireDevice) {
@@ -235,15 +219,6 @@ void Command::parse(int argc, const char *const *argv) {
   }
 }
 
-void Command::selectVolumes() {
-  // This is a separate method because it has to be called after the config
-  // file is read.
-  for(auto &selection: selections)
-    config.selectVolume(selection.host,
-                        selection.volume,
-                        selection.sense);
-}
-
 Command::LogVerbosity Command::getVerbosity(const std::string &v) {
   if(v == "all") return All;
   if(v == "errors") return Errors;
@@ -253,17 +228,12 @@ Command::LogVerbosity Command::getVerbosity(const std::string &v) {
   throw CommandError("invalid argument to --logs: " + v);
 }
 
-Command::Selection::Selection(const std::string &host_,
-                              const std::string &volume_,
-                              bool sense_): sense(sense_),
-                                            host(host_),
-                                            volume(volume_) {
-  if(!Host::valid(host) && host != "*")
-    throw CommandError("invalid host: " + host);
-  if(!Volume::valid(volume) && volume != "*")
-    throw CommandError("invalid volume: " + volume);
-  if(host == "*" && volume != "*")
-    throw CommandError("invalid host: " + host);
+Command::~Command() {
+  delete html;
+  delete text;
+  delete email;
 }
 
 Command command;
+std::string configPath = DEFAULT_CONFIG;
+std::string database;
