@@ -41,6 +41,10 @@ const int Date::mday[] = {
 };
 
 Date::Date(const std::string &dateString) {
+  *this = dateString;
+}
+
+Date &Date::operator=(const std::string &dateString) {
   long bits[3];
   const char *s = dateString.c_str();
   char *e;
@@ -69,6 +73,7 @@ Date::Date(const std::string &dateString) {
   if(bits[2] < 1 || bits[2] > monthLength(y, m))
     throw InvalidDate("invalid date string '" + dateString + "' - day out of range");
   d = bits[2];
+  return *this;
 }
 
 Date::Date(time_t when) {
@@ -83,12 +88,48 @@ Date::Date(time_t when) {
   d = result.tm_mday;
 }
 
+Date &Date::operator++() {
+  if(d < monthLength(y, m))
+    ++d;
+  else {
+    d = 1;
+    if(++m > 12) {
+      m -= 12;
+      y += 1;
+    }
+  }
+  return *this;
+}
+
+Date &Date::addMonth() {
+  m += 1;
+  if(m > 12) {
+    m -= 12;
+    y += 1;
+  }
+  d = std::min(d, monthLength(y, m));
+  return *this;
+}
+
 std::string Date::toString() const {
   char buffer[64];
   snprintf(buffer, sizeof buffer, "%04d-%02d-%02d", y, m, d);
   return buffer;
 }
 
+std::string Date::format(const char *fmt) const {
+  char buffer[256];
+  struct tm t;
+  time_t when = toTime();
+  if(!localtime_r(&when, &t)) {
+    std::stringstream ss;
+    ss << "invalid time_t: " << when << ": " << strerror(errno);
+    throw InvalidDate(ss.str());
+  }
+  strftime(buffer, sizeof buffer, fmt, &t);
+  return buffer;
+}
+
 int Date::toNumber() const {
   int dayno = 365 * y + y / 4 - y / 100 + y / 400;
   dayno += mday[m] + (m > 2 && isLeapYear() ? 1 : 0);
