@@ -79,6 +79,9 @@
 /** @brief Default path to email injector */
 #define DEFAULT_SENDMAIL _PATH_SENDMAIL
 
+/** @brief Default warning mask */
+#define DEFAULT_WARNING_MASK (WARNING_DEPRECATED|WARNING_PARTIAL|WARNING_ERRORLOGS|WARNING_DATABASE)
+
 /* Colors */
 
 /** @brief "Good" color in HTML report */
@@ -87,6 +90,9 @@
 /** @brief "Bad" color in HTML report */
 #define COLOR_BAD 0xFF4040
 
+/** @brief Default color-picking strategy */
+#define DEFAULT_COLOR_STRATEGY "equidistant-value"
+
 /* Valid names */
 
 /** @brief Lower case letters */
