@@ -14,12 +14,19 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <config.h>
 #include "Conf.h"
+#include "Backup.h"
+#include "Volume.h"
+#include "Host.h"
 #include "Subprocess.h"
-#include "Command.h"
 #include <cstdio>
 #include <cstdarg>
 #include <ostream>
 
+Host::~Host() {
+  for(auto &v: volumes)
+    delete v.second;
+}
+
 void Host::select(bool sense) {
   for(auto &v: volumes)
     v.second->select(sense);
@@ -96,7 +103,7 @@ void Host::write(std::ostream &os, int step, bool verbose) const {
   d(os, "", step);
 
   d(os,
-    "Priority for this host (higher priority = backed up earlier)",
+    "# Priority for this host (higher priority = backed up earlier)",
     step);
   d(os, "#   priority INTEGER", step);
   os << indent(step) << "priority " << priority << '\n';
