@@ -1,4 +1,4 @@
-// Copyright © 2011, 2012, 2014 Richard Kettlewell.
+// Copyright © 2011, 2012, 2014, 2016 Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -47,8 +47,7 @@ void IO::popen(const std::vector<std::string> &command,
   case ReadFromPipe: subprocess->addChildFD(1, p[1], p[0]); break;
   case WriteToPipe: subprocess->addChildFD(0, p[0], p[1]); break;
   }
-  if(verbose)
-    subprocess->report();
+  subprocess->reporting(verbose, false);
   subprocess->run();
   switch(d) {
   case ReadFromPipe:
