@@ -15,6 +15,7 @@
 #include <config.h>
 #include "rsbackup.h"
 #include "Conf.h"
+#include "Device.h"
 #include "Store.h"
 #include "Command.h"
 #include "Utils.h"
@@ -23,9 +24,10 @@
 #include "Database.h"
 #include "BulkRemove.h"
 #include <cerrno>
+#include <unistd.h>
 
 static void removeDirectory(const std::string &path) {
-  if(command.verbose)
+  if(warning_mask & WARNING_VERBOSE)
     IO::out.writef("INFO: removing %s\n", path.c_str());
   if(command.act && rmdir(path.c_str()) < 0 && errno != ENOENT) {
     error("removing %s: %s", path.c_str(), strerror(errno));
@@ -71,7 +73,7 @@ struct Retirable {
                                     + PATH_SEP + hostName
                                     + PATH_SEP + volumeName
                                     + PATH_SEP + id);
-    if(command.verbose)
+    if(warning_mask & WARNING_VERBOSE)
       IO::out.writef("INFO: removing %s\n", backupPath.c_str());
     if(command.act) {
       b = new BulkRemove(backupPath);
@@ -112,7 +114,7 @@ struct Retirable {
   }
 };
 
-// Schedulal retire of one volume or host
+// Schedule the retire of one volume or host
 static void identifyVolumes(std::vector<Retirable> &retire,
                             std::set<std::string> &volume_directories,
                             std::set<std::string> &host_directories,
