@@ -15,6 +15,7 @@
 #include <config.h>
 #include "Conf.h"
 #include "Store.h"
+#include "Device.h"
 #include "Errors.h"
 #include "IO.h"
 #include "Utils.h"
@@ -69,12 +70,13 @@ void Store::identify() {
     // unmounting.
     closeOnUnmount(f);
   } catch(IOError &e) {
-    if(f)
-      delete f;
     // Re-throw with the appropriate error type
     if(e.errno_value == ENOENT)
       throw UnavailableStore(e.what());
     else
       throw BadStore(e.what());
+  } catch(...) {
+    delete f;
+    throw;
   }
 }
