@@ -1,4 +1,4 @@
-// Copyright © 2011, 2012, 2014, 2015 Richard Kettlewell.
+// Copyright © 2011, 2012, 2014-2016 Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -15,11 +15,9 @@
 #include <config.h>
 #include "Subprocess.h"
 #include "Errors.h"
-#include "Command.h"
 #include "Defaults.h"
 #include "IO.h"
 #include "Utils.h"
-#include <limits>
 #include <csignal>
 #include <cerrno>
 #include <cstdlib>
@@ -75,6 +73,9 @@ pid_t Subprocess::launch(EventLoop *e) {
   assert(e);                            // EventLoop must already exist
   if(pid >= 0)
     throw std::logic_error("Subprocess::run but already running");
+  // Report if necessary
+  if(reportNeeded)
+    report();
   // Convert the command
   std::vector<const char *> args;
   for(auto &arg: cmd)
@@ -157,7 +158,7 @@ void Subprocess::onReadError(EventLoop *, int, int errno_value) {
 }
 
 void Subprocess::onTimeout(EventLoop *, const struct timespec &) {
-  warning("%s exceeded timeout of %d seconds",
+  warning(WARNING_ALWAYS, "%s exceeded timeout of %d seconds",
           cmd[0].c_str(), timeout);
   kill(pid, SIGKILL);
 }
@@ -175,7 +176,7 @@ void Subprocess::setup(EventLoop *e) {
     e->whenReadable(c.first, static_cast<Reactor *>(this));
   if(timeout > 0) {
     struct timespec timeLimit;
-    getTimestamp(timeLimit);
+    getMonotonicTime(timeLimit);
     if(timeLimit.tv_sec <= std::numeric_limits<time_t>::max() - timeout)
       timeLimit.tv_sec += timeout;
     else
@@ -208,6 +209,8 @@ void Subprocess::go(EventLoop *e, ActionList *al) {
 }
 
 void Subprocess::report() {
+  if(reported)
+    return;
   if(env.size()) {
     IO::out.writef("> # environment for next command\n");
     for(auto &e: env)
@@ -220,17 +223,39 @@ void Subprocess::report() {
     command += cmd[i];
   }
   IO::out.writef("> %s\n", command.c_str());
+  reported = true;
 }
 
-void Subprocess::getTimestamp(struct timespec &now) {
-#ifdef CLOCK_MONOTONIC
-  if(clock_gettime(CLOCK_MONOTONIC, &now) < 0)
-    throw IOError("clock_gettime", errno);
-#else
-  struct timeval tv;
-  if(gettimeofday(&tv, nullptr) < 0)
-    throw IOError("gettimeofday", errno);
-  now.tv_sec = tv.tv_sec;
-  now.tv_nsec = tv.tv_sec * 1000;
-#endif
+void Subprocess::reporting(bool reportCommand, bool reportNow) {
+  reportNeeded = reportCommand;
+  if(reportNeeded && reportNow)
+    report();
+}
+
+std::string Subprocess::pathSearch(const std::string &name) {
+  if(name.find('/') != std::string::npos)
+    return name;
+  const char *pathc = getenv("PATH");
+  char buffer[1024];
+  if(!pathc) {
+    // Follow documented execvp behavior
+    size_t rc = confstr(_CS_PATH, buffer, sizeof buffer);
+    if(rc == 0)
+      throw SystemError("confstr", errno);
+    if(rc > sizeof buffer)
+      throw SystemError("confstr: not enough space");
+    pathc = buffer;
+  }
+  std::string path = pathc;
+  size_t pos = 0;
+  while(pos < path.size()) {
+    size_t colon = path.find(':', pos);
+    std::string e(path, pos, colon - pos);
+    std::string p(e + "/" + name);
+    if(access(p.c_str(), X_OK) == 0)
+      return p;
+    if(!(pos = colon + 1))
+      break;
+  }
+  return "";
 }
