@@ -1,5 +1,5 @@
 //-*-C++-*-
-// Copyright © 2011, 2012, 2014, 2015 Richard Kettlewell.
+// Copyright © 2011, 2012, 2014-2016 Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -122,8 +122,19 @@ public:
    */
   pid_t run();
 
-  /** @brief Report what would be run */
-  void report();
+  /** @brief Configure reporting
+   * @param reportCommand The command must be logged
+   * @param reportNow Log command immediately
+   *
+   * If @p reportCommand is @c true then the command will be reported, either
+   * now or just before execution.
+   *
+   * If @p reportNow is @c true then if the command is to be reported, it will
+   * happen immediately.
+   *
+   * A command is never reported more than once.
+   */
+  void reporting(bool reportCommand, bool reportNow);
 
   /** @brief Wait for the subprocess.
    * @param checkStatus Throw on abnormal termination
@@ -153,6 +164,12 @@ public:
     return status;
   }
 
+  /** @brief Find @p name on the path
+   * @param name Program to execute
+   * @return Full path to @p name, or "" if not found
+   */
+  static std::string pathSearch(const std::string &name);
+
 private:
   /** @brief Process ID of child
    * Set to -1 before there is a child.
@@ -221,19 +238,14 @@ private:
    */
   void setup(EventLoop *e);
 
+  /** @brief Report what will or would be run */
+  void report();
+
   /** @brief Timeout after which child is killed, in seconds
    * 0 means no timeout: the child may run indefinitely.
    */
   int timeout = 0;
 
-  /** @brief Get a timestamp for the current time
-   * @param now Where to store timestamp
-   *
-   * If possible the monotonic clock is used.  Otherwise the real time clock is
-   * used.
-   */
-  static void getTimestamp(struct timespec &now);
-
   void onReadable(EventLoop *e, int fd, const void *ptr, size_t n) override;
   void onReadError(EventLoop *e, int fd, int errno_value) override;
   void onTimeout(EventLoop *e, const struct timespec &now) override;
@@ -248,6 +260,12 @@ private:
 
   /** @brief Private event loop */
   EventLoop *eventloop = nullptr;
+
+  /** @brief True if the command has been logged */
+  bool reported = false;
+
+  /** @brief True if the command needs to be logged */
+  bool reportNeeded = false;
 };
 
 #endif /* SUBPROCESS_H */
