@@ -25,6 +25,8 @@
 #include <cassert>
 #include <ctime>
 #include <cmath>
+#include <limits>
+#include <iostream>
 
 class IO;                               // forward declaration
 
@@ -86,6 +88,18 @@ int parseInteger(const std::string &s,
                  int min = INT_MIN, int max = INT_MAX,
                  int radix = 0);
 
+/** @brief Parse a float
+ * @param s Representation of float
+ * @param min Minimum acceptable value
+ * @param max Maximum acceptable value
+ * @return Floating point value
+ * @throws SyntaxError if the @p s doesn't represent a number
+ * @throws SyntaxError if the value is out of range
+ */
+double parseFloat(const std::string &s,
+                  double min = -std::numeric_limits<double>::max(),
+                  double max = std::numeric_limits<double>::max());
+
 /** @brief Split and parse a list represented as a string
  * @param bits Destination for components of the string
  * @param line String to parse
@@ -119,17 +133,63 @@ void error(const char *fmt, ...);
  * @param fmt Format string, as printf()
  * @param ... Arguments to format string
  *
- * Writes an error message to standard error and terminates the program.
+ * Writes an error message to standard error and terminates the program
+ * by calling @c exit().
  */
-void fatal(const char *fmt, ...);
+void fatal [[noreturn]](const char *fmt, ...);
 
 /** @brief Display a warning message
+ * @param type Warning type
  * @param fmt Format string, as printf()
  * @param ... Arguments to format string
  *
  * Writes an warning message to standard error.
  */
-void warning(const char *fmt, ...);
+void warning(unsigned type, const char *fmt, ...);
+
+/** @brief Always issue this warning */
+#define WARNING_ALWAYS      0
+
+/** @brief Display warnings for unknown devices, hosts and volumes */
+#define WARNING_UNKNOWN     0x00000001
+
+/** @brief Display warnings for unsuitable stores and unavailable devices */
+#define WARNING_STORE       0x00000002
+
+/** @brief Display warnings for deprecated configuration syntax */
+#define WARNING_DEPRECATED  0x00000004
+
+/** @brief Display rsync partial transfer warnings */
+#define WARNING_PARTIAL     0x00000008
+
+/** @brief Display verbose messages */
+#define WARNING_VERBOSE     0x00000010
+
+/** @brief Display error logs */
+#define WARNING_ERRORLOGS   0x00000020
+
+/** @brief Display warnings for database activity */
+#define WARNING_DATABASE    0x00000040
+
+/** @brief Display warnings for unreachable hosts */
+#define WARNING_UNREACHABLE 0x00000080
+
+/** @brief Current warning mask */
+extern unsigned warning_mask;
+
+/** @brief Enable warning(s)
+ * @param bits Warning bit(s) to enable
+ */
+inline void enable_warning(unsigned bits) {
+  warning_mask |= bits;
+}
+
+/** @brief Disable warning(s)
+ * @param bits Warning bit(s) to disable
+ */
+inline void disable_warning(unsigned bits) {
+  warning_mask &= ~bits;
+}
 
 /** @brief Compare timespec values */
 inline int compare_timespec(const struct timespec &a, const struct timespec &b) {
@@ -211,4 +271,71 @@ bool contains(const C &container, const E &element) {
   return container.find(element) != container.end();
 }
 
+/** @brief RFC4684 base64 alphabet for @ref write_base64() */
+extern const char rfc4684_base64[];
+
+/** @brief Convert a string to base64
+ * @param os Output stream
+ * @param s String to convert
+ * @param alphabet Digits and padding (must be 65 bytes long)
+ * @return @p os
+ */
+std::ostream &write_base64(std::ostream &os,
+                           const std::string &s,
+                           const char *alphabet = rfc4684_base64);
+
+/** @brief Expand environment variable references
+ * @param s Input string
+ * @param pos Start position within @p s
+ * @param n Number of characters to read within @p s
+ * @return @p s with environment variables expanded
+ *
+ * Within @p s:
+ *
+ * 1. The @c \ character quotes the following character.  The exception is that
+ * if it is at the end of the string, it is not replaced.
+ *
+ * 2. The sequence @c ${NAME} is replaced (nonrecursively) with the value
+ * of the environment variable @c NAME, if it is set.
+ */
+std::string substitute(const std::string &s,
+                       std::string::size_type pos = 0,
+                       std::string::size_type n = std::string::npos);
+
+/** @brief Get a timestamp for the current time
+ * @param now Where to store timestamp
+ *
+ * If possible the monotonic clock is used.  Otherwise the real time clock is
+ * used.
+ */
+void getMonotonicTime(struct timespec &now);
+
+/** @brief Issue debug output
+ *
+ * Affects the @ref D macro and @ref write_debug().
+ *
+ * The default is @c false.
+ */
+extern bool debug;
+
+/** @brief Write a debug message to standard error
+ *
+ * The arguments are the same as @c printf().  A newline is added to the output
+ * (so debug messages should not end with a newline).
+ *
+ * Only displays the a message if @ref Command::debug is set (in @ref
+ * command).
+ */
+int write_debug(const char *path, long line, const char *msg, ...);
+
+/** @brief Write a debug message to standard error
+ *
+ * The arguments are the same as @c printf().  A newline is added to the output
+ * (so debug messages should not end with a newline).
+ *
+ * Only displays the a message if @ref Command::debug is set (in @ref
+ * command).
+ */
+#define D(...) (void)(debug && write_debug(__FILE__, __LINE__, __VA_ARGS__))
+
 #endif /* UTILS_H */
