@@ -1,4 +1,4 @@
-// Copyright © 2011-2015 Richard Kettlewell.
+// Copyright © 2011-2016 Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,10 +14,30 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <config.h>
 #include "Conf.h"
+#include "Device.h"
+#include "Backup.h"
+#include "Volume.h"
+#include "Host.h"
 #include "Subprocess.h"
 #include "Utils.h"
+#include "Store.h"
 #include <cstdio>
 #include <ostream>
+#include <fnmatch.h>
+
+Volume::Volume(Host *parent_,
+               const std::string &name_,
+               const std::string &path_):
+  ConfBase(static_cast<ConfBase *>(parent_)),
+  parent(parent_),
+  name(name_),
+  path(path_) {
+  parent->addVolume(this);
+}
+
+Volume::~Volume() {
+  deleteAll(backups);
+}
 
 void Volume::select(bool sense) {
   isSelected = sense;
@@ -61,16 +81,19 @@ void Volume::calculate() {
   }
 }
 
-void Volume::addBackup(Backup *backup) {
-  backups.insert(backup);
-  calculate();
+bool Volume::addBackup(Backup *backup) {
+  bool inserted = backups.insert(backup).second;
+  if(inserted)
+    calculate();
+  return inserted;
 }
 
 bool Volume::removeBackup(const Backup *backup) {
   for(auto it = backups.begin(); it != backups.end(); ++it) {
-    const Backup *s = *it;
+    Backup *s = *it;
     if(s == backup) {
       backups.erase(it);
+      delete s;
       // Recalculate totals
       calculate();
       return true;
@@ -148,6 +171,30 @@ bool Volume::available() const {
   return true;
 }
 
+BackupRequirement Volume::needsBackup(Device *device) {
+  switch(fnmatch(devicePattern.c_str(), device->name.c_str(),
+                 FNM_NOESCAPE)) {
+  case 0:
+    break;
+  case FNM_NOMATCH:
+    return NotThisDevice;
+  default:
+    warning(WARNING_ALWAYS, "invalid device pattern '%s'",
+            devicePattern.c_str());
+    /* fail safe - make the backup */
+    break;
+  }
+  Date today = Date::today();
+  for(const Backup *backup: backups)
+    if(backup->rc == 0
+       && backup->date == today
+       && backup->deviceName == device->name)
+      return AlreadyBackedUp;           // Already backed up
+  if(!available())
+    return NotAvailable;
+  return BackupRequired;
+}
+
 void Volume::write(std::ostream &os, int step, bool verbose) const {
   describe_type *d = verbose ? describe : nodescribe;
 
