@@ -30,8 +30,6 @@
 #include <cstdlib>
 #include <cerrno>
 #include <sstream>
-#include <iostream>
-#include <iomanip>
 
 int main(int argc, char **argv) {
   try {
@@ -49,7 +47,7 @@ int main(int argc, char **argv) {
 
     // Dump configuration
     if(command.dumpConfig) {
-      config.write(std::cout, 0, command.verbose);
+      config.write(std::cout, 0, !!(warning_mask & WARNING_VERBOSE));
       exit(0);
     }
 
@@ -78,15 +76,15 @@ int main(int argc, char **argv) {
       if(!lockFile.acquire(command.wait)) {
         // Failing to acquire the lock is not really an error if --wait was not
         // requested.
-        if(command.verbose)
-          warning("cannot acquire lockfile %s", config.lock.c_str());
+        warning(WARNING_VERBOSE,
+                "cannot acquire lockfile %s", config.lock.c_str());
         exit(0);
       }
     }
 
     // Select volumes
     if(command.backup || command.prune || command.pruneIncomplete)
-      command.selectVolumes();
+      command.selections.select(config);
 
     // Execute commands
     if(command.backup)
@@ -116,13 +114,9 @@ int main(int argc, char **argv) {
         d.htmlStyleSheet = stylesheet;
       // Include user colors in the stylesheet
       std::stringstream ss;
-      ss << std::hex;
-      ss << "td.bad { background-color: #"
-         << std::setw(6) << std::setfill('0') << config.colorBad << " }\n";
-      ss << "td.good { background-color: #"
-         << std::setw(6) << std::setfill('0')  << config.colorGood << " }\n";
-      ss << "span.bad { color: #"
-         << std::setw(6) << std::setfill('0')  << config.colorBad << " }\n";
+      ss << "td.bad { background-color: #" << config.colorBad << " }\n";
+      ss << "td.good { background-color: #" << config.colorGood << " }\n";
+      ss << "span.bad { color: #" << config.colorBad << " }\n";
       d.htmlStyleSheet += ss.str();
       Report report(d);
       report.generate();
@@ -188,12 +182,12 @@ int main(int argc, char **argv) {
         e.send();
       }
     }
-    if(errors && command.verbose)
-      warning("%d errors detected", errors);
+    if(errors)
+      warning(WARNING_VERBOSE, "%d errors detected", errors);
     IO::out.close();
   } catch(Error &e) {
     error("%s", e.what());
-    if(command.debug)
+    if(debug)
       e.trace(stderr);
   } catch(std::runtime_error &e) {
     error("%s", e.what());
