@@ -1,5 +1,5 @@
 //-*-C++-*-
-// Copyright © 2011, 2012 Richard Kettlewell.
+// Copyright © 2011, 2012, 2015 Richard Kettlewell.
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -39,9 +39,6 @@ void pruneBackups();
 /** @brief Prune redundant logs */
 void prunePruneLogs();
 
-/** @brief Generate the report */
-void generateReport(Document &d);
-
 /** @brief HTML stylesheet */
 extern char stylesheet[];
 
