@@ -14,7 +14,7 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <config.h>
 #include "Errors.h"
-#include "Conf.h"
+#include "ConfBase.h"
 #include <cassert>
 
 void test_quote() {
