@@ -14,6 +14,8 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <config.h>
 #include "Conf.h"
+#include "Backup.h"
+#include "Volume.h"
 #include <getopt.h>
 #include <cassert>
 
@@ -27,6 +29,5 @@ int main() {
   assert(!Volume::valid(" "));
   assert(!Volume::valid("\x1F"));
   assert(!Volume::valid("-whatever"));
-  assert(Host::valid("what-are-the-civilian-applications"));
   return 0;
 }
